// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef KPLOTTING_VERSION_H
#define KPLOTTING_VERSION_H

#define KPLOTTING_VERSION_STRING "5.110.0"
#define KPLOTTING_VERSION_MAJOR 5
#define KPLOTTING_VERSION_MINOR 110
#define KPLOTTING_VERSION_PATCH 0
#define KPLOTTING_VERSION ((5<<16)|(110<<8)|(0))

#endif
